OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Ви створили нову дошку {board}",
    "{user} has created a new board {board}" : "{user} створив нову дошку {board}",
    "You have deleted the board {board}" : "Ви вилучили дошку {board}",
    "{user} has deleted the board {board}" : "{user} вилучив дошку {board}",
    "You have restored the board {board}" : "Ви відновили дошку {board}",
    "{user} has restored the board {board}" : "{user} відновив дошку {board}",
    "You have shared the board {board} with {acl}" : "Ви поділилися дошкою {board} з {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} поділився дошкою {board} з {acl}",
    "You have removed {acl} from the board {board}" : "Ви вилучили {acl} з дошки {board}",
    "{user} has removed {acl} from the board {board}" : "{user} вилучив {acl} з дошки {board}",
    "You have renamed the board {before} to {board}" : "Ви перейменували дошку з {before} у {board}",
    "Deck" : "Колода",
    "Changes in the <strong>Deck app</strong>" : "Зміни у застосунку <strong>Колода</strong>",
    "Personal" : "Особисте",
    "Finished" : "Завершено",
    "To review" : "На перегляд",
    "Action needed" : "Потребує дій",
    "Later" : "Пізніше",
    "copy" : "копіювати",
    "Done" : "Готово",
    "The file was uploaded" : "Файл завантажено",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Файл для завантаження перевищує параметр upload_max_filesize у php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Розмір вивантаженого файлу перевищує директиву MAX_FILE_SIZE вказану в HTML формі",
    "The file was only partially uploaded" : "Файл завантажено лише частково",
    "No file was uploaded" : "Не вивантажено жодного файлу",
    "Missing a temporary folder" : "Відсутній тимчасовий каталог",
    "Could not write file to disk" : "Неможливо записати файл на диск",
    "A PHP extension stopped the file upload" : "Розширення PHP призупинило завантаження файлу",
    "Create new board" : "Створити нову дошку",
    "Cancel" : "Скасувати",
    "File already exists" : "Файл вже існує",
    "Drop your files to upload" : "Пересуньте файли сюди для завантаження",
    "Archived cards" : "Архівні картки",
    "Filter by tag" : "Відібрати за позначками",
    "Filter by assigned user" : "Відібрати за призначеним користувачем",
    "Filter by due date" : "Відібрати за датою завершення",
    "Overdue" : "Протерміновано",
    "Next 7 days" : "Наступні 7 днів",
    "Next 30 days" : "Наступні 30 днів",
    "No due date" : "Без дати завершення",
    "Show archived cards" : "Показати архівні картки",
    "Details" : "Деталі",
    "Sharing" : "Поділитись",
    "Tags" : "Теги",
    "Undo" : "відмінити",
    "(Group)" : "(група)",
    "Can edit" : "Можна редагувати",
    "Can share" : "Can share",
    "Delete" : "Вилучити",
    "Add a new stack" : "Додати нову купу",
    "Delete list" : "Вилучити список",
    "Add card" : "Додати картку",
    "Edit" : "Редагувати",
    "Title" : "Назва",
    "Members" : "Учасники",
    "Due date" : "Протягом",
    "Remove due date" : "Вилучити до",
    "Description" : "Опис",
    "Formatting help" : "Форматування довідки",
    "Attachments" : "Вкладення",
    "Comments" : "Коментарі",
    "Modified" : "Змінено",
    "Upload attachment" : "Завантажити вкладення",
    "Save" : "Зберегти",
    "Reply" : "Відповісти",
    "Update" : "Оновлення",
    "(group)" : "(група)",
    "seconds ago" : "секунд тому",
    "Archive card" : "Архівувати картку",
    "Delete card" : "Вилучити картку",
    "Move card" : "Пересунути картку",
    "Archived boards" : "Архівні дошки",
    "Shared with you" : "Вам надано доступ",
    "Settings" : "Налаштування",
    "New board title" : "Новий заголовок дошки",
    "Edit board" : "Змінити дошку",
    "Board details" : "Деталі дошки",
    "An error occurred" : "Виникла помилка"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
